@@ -246,6 +246,16 @@ class MainWindow(QtGui.QMainWindow):
             )
         self.addAction(self.openeditablefile_action)  
 
+        try:
+            import globusonline.catalog.client.examples.catalog_wrapper
+            self.openremotefile_action=QtGui.QAction("Open Remote...",
+                self,
+                triggered=self.open_remote_file
+                )
+            self.add_menu_action(self.file_menu, self.openremotefile_action)
+        except ImportError:
+            pass
+
         self.savefile_action=QtGui.QAction("&Save as...",
             self,
             shortcut=QtGui.QKeySequence.Save,
@@ -809,6 +819,13 @@ class MainWindow(QtGui.QMainWindow):
         except (NeXusError, IOError) as error:
             report_error("Opening File (Read/Write)", error)
 
+    def open_remote_file(self):
+        try:
+            dialog = RemoteDialog(self)
+            dialog.show()
+        except NeXusError as error:
+            report_error("Opening Remote File", error)
+
     def save_file(self):
         try:
             node = self.treeview.get_node()
@@ -931,7 +948,10 @@ class MainWindow(QtGui.QMainWindow):
                     raise NeXusError('Imported data must be an NXroot or NXentry group')
                 self.treeview.select_node(self.treeview.tree[name])
                 self.treeview.setFocus()
-                self.default_directory = os.path.dirname(self.import_dialog.import_file)
+                try:
+                    self.default_directory = os.path.dirname(self.import_dialog.import_file)
+                except Exception:
+                    pass
                 logging.info("Workspace '%s' imported" % name)               
         except NeXusError as error:
             report_error("Importing File", error)
@@ -954,10 +974,7 @@ class MainWindow(QtGui.QMainWindow):
             node = self.treeview.get_node()
             if node:        
                 self.treeview.status_message(node)
-                try:
-                    node.oplot(fmt)
-                except:
-                    pass
+                node.oplot(fmt)
         except NeXusError as error:
             report_error("Overplotting Data", error)
 
@@ -1047,7 +1064,7 @@ class MainWindow(QtGui.QMainWindow):
         try:
             node = self.treeview.get_node()
             if node:
-                if node.nxfilemode != 'r':
+                if node.nxroot.nxfilemode != 'r':
                     path = node.nxpath
                     dialog = DeleteDialog(node, self)
                     dialog.show()
@@ -1061,7 +1078,20 @@ class MainWindow(QtGui.QMainWindow):
         try:
             node = self.treeview.get_node()
             if isinstance(node, NXlink):
-                self.treeview.select_node(node.nxlink)
+                if node.nxfilename != node.nxroot.nxfilename:
+                    fname = node.nxfilename
+                    if not os.path.isabs(fname):
+                        fname = os.path.join(os.path.dirname(node.nxroot.nxfilename),
+                                             node.nxfilename)
+                    try:
+                        name = self.treeview.tree.node_from_file(fname)
+                    except IndexError:    
+                        name = self.treeview.tree.get_name(fname)
+                        self.treeview.tree[name] = self.user_ns[name] = nxload(fname)
+                    self.treeview.select_node(self.treeview.tree[name][node.nxtarget])
+                    self.treeview.setFocus()
+                else:
+                    self.treeview.select_node(node.nxlink)
                 self.treeview.update()
         except NeXusError as error:
             report_error("Showing Link", error)
@@ -1277,7 +1307,7 @@ class MainWindow(QtGui.QMainWindow):
                 checkable=True)
             self.window_menu.addAction(self.active_action[number])
         else:
-            numbers = sorted(self.active_action.keys())
+            numbers = [num for num in sorted(self.active_action.keys()) if num < 100]
             if number > numbers[-1]:
                 before_action = self.window_separator
             else:
@@ -1331,7 +1361,7 @@ class MainWindow(QtGui.QMainWindow):
     def reset_axes(self):
         try:
             from nexpy.gui.plotview import plotview
-            plotview.reset_limits()
+            plotview.reset_plot_limits()
         except NeXusError as error:
             report_error("Resetting Plot Limits", error)
 
